==> resim_open_core-0.1.0-py3-none-manylinux2014_x86_64.whl: resim_python_client/api/reports/create_report_metrics_data.py <==
from http import HTTPStatus
from typing import Any, Dict, Optional, Union, cast

import httpx

from ...client import AuthenticatedClient, Client
from ...types import Response
from ... import errors

from ...models.metrics_data import MetricsData


def _get_kwargs(
    project_id: str,
    report_id: str,
    *,
    body: MetricsData,
) -> Dict[str, Any]:
    headers: Dict[str, Any] = {}

    _kwargs: Dict[str, Any] = {
        "method": "post",
        "url": "/projects/{project_id}/reports/{report_id}/metricsData".format(
            project_id=project_id,
            report_id=report_id,
        ),
    }

    _body = body.to_dict()

    _kwargs["json"] = _body
    headers["Content-Type"] = "application/json"

    _kwargs["headers"] = headers
    return _kwargs


def _parse_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Optional[Union[Any, MetricsData]]:
    if response.status_code == HTTPStatus.CREATED:
        response_201 = MetricsData.from_dict(response.json())

        return response_201
    if response.status_code == HTTPStatus.UNAUTHORIZED:
        response_401 = cast(Any, None)
        return response_401
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Response[Union[Any, MetricsData]]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    project_id: str,
    report_id: str,
    *,
    client: AuthenticatedClient,
    body: MetricsData,
) -> Response[Union[Any, MetricsData]]:
    """Creates a new metrics data associated with a report. If this metrics data is an external file, then
    the filename field must be populated.

    Args:
        project_id (str):
        report_id (str):
        body (MetricsData):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[Any, MetricsData]]
    """

    kwargs = _get_kwargs(
        project_id=project_id,
        report_id=report_id,
        body=body,
    )

    response = client.get_httpx_client().request(
        **kwargs,
    )

    return _build_response(client=client, response=response)


def sync(
    project_id: str,
    report_id: str,
    *,
    client: AuthenticatedClient,
    body: MetricsData,
) -> Optional[Union[Any, MetricsData]]:
    """Creates a new metrics data associated with a report. If this metrics data is an external file, then
    the filename field must be populated.

    Args:
        project_id (str):
        report_id (str):
        body (MetricsData):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[Any, MetricsData]
    """

    return sync_detailed(
        project_id=project_id,
        report_id=report_id,
        client=client,
        body=body,
    ).parsed


async def asyncio_detailed(
    project_id: str,
    report_id: str,
    *,
    client: AuthenticatedClient,
    body: MetricsData,
) -> Response[Union[Any, MetricsData]]:
    """Creates a new metrics data associated with a report. If this metrics data is an external file, then
    the filename field must be populated.

    Args:
        project_id (str):
        report_id (str):
        body (MetricsData):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[Any, MetricsData]]
    """

    kwargs = _get_kwargs(
        project_id=project_id,
        report_id=report_id,
        body=body,
    )

    response = await client.get_async_httpx_client().request(**kwargs)

    return _build_response(client=client, response=response)


async def asyncio(
    project_id: str,
    report_id: str,
    *,
    client: AuthenticatedClient,
    body: MetricsData,
) -> Optional[Union[Any, MetricsData]]:
    """Creates a new metrics data associated with a report. If this metrics data is an external file, then
    the filename field must be populated.

    Args:
        project_id (str):
        report_id (str):
        body (MetricsData):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[Any, MetricsData]
    """

    return (
        await asyncio_detailed(
            project_id=project_id,
            report_id=report_id,
            client=client,
            body=body,
        )
    ).parsed

==> resim_open_core-0.3.1-py3-none-manylinux2014_x86_64.whl: resim_python_client/api/reports/create_report_metrics_data.py <==
from http import HTTPStatus
from typing import Any, Dict, List, Optional, Union, cast

import httpx

from ...client import AuthenticatedClient, Client
from ...types import Response, UNSET
from ... import errors

from typing import Dict
from ...models.metrics_data import MetricsData
from typing import cast



def _get_kwargs(
    project_id: str,
    report_id: str,
    *,
    body: MetricsData,

) -> Dict[str, Any]:
    headers: Dict[str, Any] = {}


    

    

    _kwargs: Dict[str, Any] = {
        "method": "post",
        "url": "/projects/{project_id}/reports/{report_id}/metricsData".format(project_id=project_id,report_id=report_id,),
    }

    _body = body.to_dict()


    _kwargs["json"] = _body
    headers["Content-Type"] = "application/json"

    _kwargs["headers"] = headers
    return _kwargs


def _parse_response(*, client: Union[AuthenticatedClient, Client], response: httpx.Response) -> Optional[Union[Any, MetricsData]]:
    if response.status_code == HTTPStatus.CREATED:
        response_201 = MetricsData.from_dict(response.json())



        return response_201
    if response.status_code == HTTPStatus.UNAUTHORIZED:
        response_401 = cast(Any, None)
        return response_401
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(*, client: Union[AuthenticatedClient, Client], response: httpx.Response) -> Response[Union[Any, MetricsData]]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    project_id: str,
    report_id: str,
    *,
    client: AuthenticatedClient,
    body: MetricsData,

) -> Response[Union[Any, MetricsData]]:
    """  Creates a new metrics data associated with a report. If this metrics data is an external file, then
    the filename field must be populated.

    Args:
        project_id (str):
        report_id (str):
        body (MetricsData):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[Any, MetricsData]]
     """


    kwargs = _get_kwargs(
        project_id=project_id,
report_id=report_id,
body=body,

    )

    response = client.get_httpx_client().request(
        **kwargs,
    )

    return _build_response(client=client, response=response)

def sync(
    project_id: str,
    report_id: str,
    *,
    client: AuthenticatedClient,
    body: MetricsData,

) -> Optional[Union[Any, MetricsData]]:
    """  Creates a new metrics data associated with a report. If this metrics data is an external file, then
    the filename field must be populated.

    Args:
        project_id (str):
        report_id (str):
        body (MetricsData):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[Any, MetricsData]
     """


    return sync_detailed(
        project_id=project_id,
report_id=report_id,
client=client,
body=body,

    ).parsed

async def asyncio_detailed(
    project_id: str,
    report_id: str,
    *,
    client: AuthenticatedClient,
    body: MetricsData,

) -> Response[Union[Any, MetricsData]]:
    """  Creates a new metrics data associated with a report. If this metrics data is an external file, then
    the filename field must be populated.

    Args:
        project_id (str):
        report_id (str):
        body (MetricsData):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[Any, MetricsData]]
     """


    kwargs = _get_kwargs(
        project_id=project_id,
report_id=report_id,
body=body,

    )

    response = await client.get_async_httpx_client().request(
        **kwargs
    )

    return _build_response(client=client, response=response)

async def asyncio(
    project_id: str,
    report_id: str,
    *,
    client: AuthenticatedClient,
    body: MetricsData,

) -> Optional[Union[Any, MetricsData]]:
    """  Creates a new metrics data associated with a report. If this metrics data is an external file, then
    the filename field must be populated.

    Args:
        project_id (str):
        report_id (str):
        body (MetricsData):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[Any, MetricsData]
     """


    return (await asyncio_detailed(
        project_id=project_id,
report_id=report_id,
client=client,
body=body,

    )).parsed
